Assorted spelling fixes

Francois Gouget fgouget at free.fr
Mon Jul 11 05:19:45 CDT 2005


Changelog:

  * dlls/advapi32/lsa.c
    dlls/comctl32/tests/dpa.c
    dlls/d3d8/device.c
    dlls/d3d9/stateblock.c
    dlls/ddraw/surface_dib.c
    dlls/dmime/tempotrack.c
    dlls/shell32/shlexec.c
    dlls/shell32/tests/shlfolder.c
    dlls/wined3d/device.c
    dlls/wined3d/directx.c
    dlls/wined3d/drawprim.c
    dlls/wined3d/stateblock.c
    dlls/wined3d/surface.c
    dlls/wined3d/swapchain.c
    dlls/wined3d/vertexdeclaration.c
    programs/winedbg/winedbg.man

    Francois Gouget <fgouget at free.fr>
    Assorted spelling fixes

-- 
Francois Gouget         fgouget at free.fr        http://fgouget.free.fr/
In theory, theory and practice are the same, but in practice they're different.
-------------- next part --------------
Index: dlls/comctl32/tests/dpa.c
===================================================================
RCS file: /var/cvs/wine/dlls/comctl32/tests/dpa.c,v
retrieving revision 1.11
diff -u -p -r1.11 dpa.c
--- dlls/comctl32/tests/dpa.c	8 Jul 2005 11:30:28 -0000	1.11
+++ dlls/comctl32/tests/dpa.c	8 Jul 2005 16:50:37 -0000
@@ -284,7 +284,7 @@ static void test_dpa(void)
         todo_wine ok(j+1 == i, "j=%d i=%d\n", j, i);
     }
     
-    /* Try to get the index of a non-existent item */
+    /* Try to get the index of a nonexistent item */
     i = pDPA_GetPtrIndex(dpa, (PVOID)7);
     ok(i == DPA_ERR, "i=%d\n", i);
     
Index: dlls/d3d8/device.c
===================================================================
RCS file: /var/cvs/wine/dlls/d3d8/device.c,v
retrieving revision 1.125
diff -u -p -r1.125 device.c
--- dlls/d3d8/device.c	27 May 2005 20:17:37 -0000	1.125
+++ dlls/d3d8/device.c	7 Jul 2005 22:47:00 -0000
@@ -4608,7 +4608,7 @@ HRESULT WINAPI IDirect3DDevice8Impl_Acti
       vcheckGLcall("glFlush");
 
 #ifdef EXTRA_TRACES
-      /** very very usefull debug code */
+      /** very very useful debug code */
       glXSwapBuffers(This->display, This->drawable);   
       printf("Hit Enter to get next frame ...\n");
       getchar();
Index: dlls/d3d9/stateblock.c
===================================================================
RCS file: /var/cvs/wine/dlls/d3d9/stateblock.c,v
retrieving revision 1.9
diff -u -p -r1.9 stateblock.c
--- dlls/d3d9/stateblock.c	5 Jul 2005 16:17:31 -0000	1.9
+++ dlls/d3d9/stateblock.c	5 Jul 2005 23:12:04 -0000
@@ -138,13 +138,15 @@ HRESULT  WINAPI  IDirect3DDevice9Impl_En
 
     TRACE("(%p) Relay\n", This); 
     
-    /*Tell wineD3D to endstatablock before anything else (incase we run out of memory later and cause locking problems)*/
+    /* Tell wineD3D to endstatablock before anything else (in case we run out
+     * of memory later and cause locking problems)
+     */
     hr=IWineD3DDevice_EndStateBlock(This->WineD3DDevice,&wineD3DStateBlock);
     if(hr!= D3D_OK){
        FIXME("IWineD3DDevice_EndStateBlock returned an error\n");
        return hr;
     }    
-    /*allocate a new IDirectD3DStateBlock*/
+    /* allocate a new IDirectD3DStateBlock */
     object = HeapAlloc(GetProcessHeap(), HEAP_ZERO_MEMORY ,sizeof(IDirect3DStateBlock9Impl));      
     object->ref = 1;
     object->lpVtbl = &Direct3DStateBlock9_Vtbl;
Index: dlls/ddraw/surface_dib.c
===================================================================
RCS file: /var/cvs/wine/dlls/ddraw/surface_dib.c,v
retrieving revision 1.1
diff -u -p -r1.1 surface_dib.c
--- dlls/ddraw/surface_dib.c	5 Jun 2005 17:50:49 -0000	1.1
+++ dlls/ddraw/surface_dib.c	7 Jul 2005 22:47:19 -0000
@@ -476,7 +476,7 @@ static void DoDXTCDecompression(const DD
 		    *((DWORD*)(dst+y*pitch+x*(is16?2:4))) = pixel;
 	    }
     }
-#if 0 /* Usefull for debugging */
+#if 0 /* Useful for debugging */
     {
 	static int idx;
 	char texname[255];
Index: dlls/dmime/tempotrack.c
===================================================================
RCS file: /var/cvs/wine/dlls/dmime/tempotrack.c,v
retrieving revision 1.16
diff -u -p -r1.16 tempotrack.c
--- dlls/dmime/tempotrack.c	21 Jun 2005 09:44:28 -0000	1.16
+++ dlls/dmime/tempotrack.c	7 Jul 2005 22:47:34 -0000
@@ -117,7 +117,7 @@ static HRESULT WINAPI IDirectMusicTempoT
     ERR(": no more memory\n");
     return E_OUTOFMEMORY;
   }
-  /** TODO real fill usefull datas */
+  /** TODO real fill useful datas */
   pState->dummy = 0;
   *ppStateData = pState;
   return S_OK;
Index: dlls/shell32/shlexec.c
===================================================================
RCS file: /var/cvs/wine/dlls/shell32/shlexec.c,v
retrieving revision 1.65
diff -u -p -r1.65 shlexec.c
--- dlls/shell32/shlexec.c	14 Jun 2005 19:17:41 -0000	1.65
+++ dlls/shell32/shlexec.c	7 Jul 2005 22:47:53 -0000
@@ -743,7 +743,7 @@ UINT SHELL_FindExecutable(LPCWSTR lpPath
 /******************************************************************
  *		dde_cb
  *
- * callback for the DDE connection. not really usefull
+ * callback for the DDE connection. not really useful
  */
 static HDDEDATA CALLBACK dde_cb(UINT uType, UINT uFmt, HCONV hConv,
                                 HSZ hsz1, HSZ hsz2, HDDEDATA hData,
Index: dlls/shell32/tests/shlfolder.c
===================================================================
RCS file: /var/cvs/wine/dlls/shell32/tests/shlfolder.c,v
retrieving revision 1.23
diff -u -p -r1.23 shlfolder.c
--- dlls/shell32/tests/shlfolder.c	8 Jul 2005 11:30:18 -0000	1.23
+++ dlls/shell32/tests/shlfolder.c	8 Jul 2005 23:36:17 -0000
@@ -131,8 +131,8 @@ static void test_EnumObjects(IShellFolde
     hr = IShellFolder_EnumObjects(iFolder, NULL, SHCONTF_FOLDERS | SHCONTF_NONFOLDERS | SHCONTF_INCLUDEHIDDEN, &iEnumList);
     ok(hr == S_OK, "EnumObjects failed %08lx\n", hr);
 
-    /* This is to show that, contrary to what is said on MSDN on IEnumIDList::Next,
-     * the filesystem shellfolders return S_OK even if less then 'celt' items are
+    /* This is to show that, contrary to what is said on MSDN, on IEnumIDList::Next,
+     * the filesystem shellfolders return S_OK even if less than 'celt' items are
      * returned (in contrast to S_FALSE). We have to do it in a loop since WinXP
      * only ever returns a single entry per call. */
     while (IEnumIDList_Next(iEnumList, 10-i, &idlArr[i], &NumPIDLs) == S_OK) 
Index: dlls/wined3d/drawprim.c
===================================================================
RCS file: /var/cvs/wine/dlls/wined3d/drawprim.c,v
retrieving revision 1.11
diff -u -p -r1.11 drawprim.c
--- dlls/wined3d/drawprim.c	7 Jul 2005 20:45:39 -0000	1.11
+++ dlls/wined3d/drawprim.c	7 Jul 2005 22:14:04 -0000
@@ -430,7 +430,7 @@ void primitiveDeclarationConvertToStride
 
         break;
         case D3DDECLUSAGE_TEXCOORD:
-        /* For some odd reason Microsoft desided to sum usage accross all the streams,
+        /* For some odd reason Microsoft decided to sum usage accross all the streams,
         which means we need to do a count and not just use the usage number */
 
             strided->u.s.texCoords[textureNo].lpData    = data;
@@ -451,9 +451,9 @@ void primitiveDeclarationConvertToStride
         TRACE("Tangents\n");
         break;
         case D3DDECLUSAGE_BINORMAL:
-        /* Binormals are really bitangents perpendicular to the normal but s-aligned to the tangent, basicly they are the vectors of any two lines on the plain at right angles to the normal and at right angles to each other, like the x,y,z axis.
-        tangent data makes it easier to perform some calcualtions (a bit like using 2d graph paper instead of the normal of the piece of paper)
-        The only thing they are usefull for in fixed function would be working out normals when none are give.
+        /* Binormals are really bitangents perpendicular to the normal but s-aligned to the tangent, basically they are the vectors of any two lines on the plain at right angles to the normal and at right angles to each other, like the x,y,z axis.
+        tangent data makes it easier to perform some calculations (a bit like using 2d graph paper instead of the normal of the piece of paper)
+        The only thing they are useful for in fixed function would be working out normals when none are given.
         */
 #if 0
         strided->u.s.binormal.lpData   = data;
@@ -464,7 +464,7 @@ void primitiveDeclarationConvertToStride
         TRACE("BI-Normal\n");
         break;
         case D3DDECLUSAGE_TESSFACTOR:
-        /* a google for D3DDECLUSAGE_TESSFACTOR turns up a wopping 36 entries, 7 of which are from MSDN.
+        /* a google for D3DDECLUSAGE_TESSFACTOR turns up a whopping 36 entries, 7 of which are from MSDN.
         */
 #if 0
         strided->u.s.tessFacrot.lpData   = data;
Index: dlls/wined3d/stateblock.c
===================================================================
RCS file: /var/cvs/wine/dlls/wined3d/stateblock.c,v
retrieving revision 1.11
diff -u -p -r1.11 stateblock.c
--- dlls/wined3d/stateblock.c	5 Jul 2005 14:05:18 -0000	1.11
+++ dlls/wined3d/stateblock.c	5 Jul 2005 17:26:31 -0000
@@ -377,7 +377,7 @@ should really perform a delta so that on
 
         /* FIXME: Texture are set against samplers... not just TextureStages */
         /* Texture */
-        for (j = 0; j < GL_LIMITS(textures); j++) { /* Set The texture first, just incase it resets the states? */
+        for (j = 0; j < GL_LIMITS(textures); j++) { /* Set The texture first, just in case it resets the states? */
             if (This->set.textures[j] && This->changed.textures[j]) {
                 IWineD3DDevice_SetTexture(pDevice, j, This->textures[j]);
             }
Index: dlls/wined3d/vertexdeclaration.c
===================================================================
RCS file: /var/cvs/wine/dlls/wined3d/vertexdeclaration.c,v
retrieving revision 1.8
diff -u -p -r1.8 vertexdeclaration.c
--- dlls/wined3d/vertexdeclaration.c	7 Jul 2005 20:45:39 -0000	1.8
+++ dlls/wined3d/vertexdeclaration.c	7 Jul 2005 22:28:29 -0000
@@ -340,7 +340,7 @@ IWineD3DVertexDeclarationImpl *This = (I
 #if 0 /* TODO: This looks like overkill so I've removed it. */
   {
     D3DVERTEXELEMENT9* pIt = This->pDeclaration9;
-    TRACE("dumping of D3D9 Convertion:\n");
+    TRACE("dumping of D3D9 Conversion:\n");
     while (0xFF != pIt->Stream) {
       IWineD3DVertexDeclarationImpl_ParseToken9(pIt);
       ++pIt;
Index: programs/winedbg/winedbg.man
===================================================================
RCS file: /var/cvs/wine/programs/winedbg/winedbg.man,v
retrieving revision 1.2
diff -u -p -r1.2 winedbg.man
--- programs/winedbg/winedbg.man	3 Jan 2005 14:38:03 -0000	1.2
+++ programs/winedbg/winedbg.man	7 Jul 2005 22:48:17 -0000
@@ -32,7 +32,7 @@ mode. \fBwinedbg\fR will act as the fron
 .IP \fB--auto\fR
 This mode is used when \fBwinedbg\fR is setup in \fIAeDebug\fR
 registry entry as the default debugger. \fBwinedbg\fR will then
-display basic information about a crash. This is usefull for users
+display basic information about a crash. This is useful for users
 who don't want to debug a crash, but rather gather relevant
 information about the crash to be sent to developers.
 .IP \fB--gdb\fR
@@ -45,7 +45,7 @@ Only the \fBgdb\fR proxy mode allows som
 .PP
 .IP \fI--no-start\fR \fBgdb\fR will not be automatically
 started. Relevant information for starting \fBgdb\fR are printed on
-screen. This is somehow usefull when not directly using \fBgdb\fR but
+screen. This is somehow useful when not directly using \fBgdb\fR but
 some graphical front-ends, like \fBddd\fR or \fBkgbd\fR. 
 .IP \fI--with-xterm\fR
 This will run \fBgdb\fR in its own xterm instead of using the current


More information about the wine-patches mailing list
Index: dlls/advapi32/lsa.c
===================================================================
RCS file: /var/cvs/wine/dlls/advapi32/lsa.c,v
retrieving revision 1.1
diff -u -p -r1.1 lsa.c
--- dlls/advapi32/lsa.c	6 Jul 2005 10:37:50 -0000	1.1
+++ dlls/advapi32/lsa.c	11 Jul 2005 09:57:58 -0000
@@ -104,7 +104,7 @@ NTSTATUS WINAPI LsaClose(IN LSA_HANDLE O
  *  PolicyHandle          [I] Handle to a Policy object.
  *  EnumerationContext    [I] Pointer to an enumeration handle.
  *  Buffer                [O] Contains the names and SIDs of trusted domains.
  *  PreferedMaximumLength [I] Prefered maximum size in bytes of Buffer.
  *  CountReturned         [O] Number of elements in Buffer.
  *
  * RETURNS
@@ -121,11 +121,11 @@ NTSTATUS WINAPI LsaEnumerateTrustedDomai
     IN LSA_HANDLE PolicyHandle,
     IN PLSA_ENUMERATION_HANDLE EnumerationContext,
     OUT PVOID* Buffer,
-    IN ULONG PreferedMaximumLength,
+    IN ULONG PreferredMaximumLength,
     OUT PULONG CountReturned)
 {
     FIXME("(%p,%p,%p,0x%08lx,%p) stub\n", PolicyHandle, EnumerationContext,
-          Buffer, PreferedMaximumLength, CountReturned);
+          Buffer, PreferredMaximumLength, CountReturned);
 
     if (CountReturned) *CountReturned = 0;
     return STATUS_SUCCESS;
@@ -104,7 +104,7 @@ NTSTATUS WINAPI LsaClose(IN LSA_HANDLE O
  *  EnumerationContext    [I] Pointer to an enumeration handle.
  *  Buffer                [O] Contains the names and SIDs of trusted domains.
- *  PreferedMaximumLength [I] Prefered maximum size in bytes of Buffer.
+ *  PreferredMaximumLength[I] Preferred maximum size in bytes of Buffer.
  *  CountReturned         [O] Number of elements in Buffer.
  *
Index: dlls/wined3d/device.c
===================================================================
RCS file: /var/cvs/wine/dlls/wined3d/device.c,v
retrieving revision 1.40
diff -u -p -r1.40 device.c
--- dlls/wined3d/device.c	10 Jul 2005 18:16:13 -0000	1.40
+++ dlls/wined3d/device.c	10 Jul 2005 19:58:44 -0000
@@ -299,12 +299,12 @@ ULONG WINAPI IWineD3DDeviceImpl_Release(
         /* TODO: Clean up all the surfaces and textures! */
         /* FIXME: Create targets and state blocks in d3d8 */        
         if (((IWineD3DImpl *)This->wineD3D)->dxVersion > 8) { /*We don't create a state block in d3d8 yet*/
-            /* NOTE: You must release the parent if the objects was created via a callback
+            /* NOTE: You must release the parent if the object was created via a callback
             ** ***************************/
             int i;
             IUnknown* swapChainParent;
 
             /* Release all of the swapchains, except the implicite swapchain (#0) */
             for(i = 1; i < This->numberOfSwapChains; i++){
                 /*  TODO: don't access swapchains[x] directly! */
                 IWineD3DSwapChain_Release(This->swapchains[i]);
@@ -315,12 +315,12 @@ ULONG WINAPI IWineD3DDeviceImpl_Release(
             }
 
             if (This->swapchains[0] != NULL) {
-                /* Swapchain 0 is special because it's created in startup with a hanging parent, so we have to release it's parent now */
+                /* Swapchain 0 is special because it's created in startup with a hanging parent, so we have to release its parent now */
                 /*  TODO: don't access swapchains[x] directly!, check that there are no-more swapchains left for this device! */
                 IWineD3DSwapChain_GetParent(This->swapchains[0], &swapChainParent);
                 IUnknown_Release(swapChainParent);           /* once for the get parent */
                 if (IUnknown_Release(swapChainParent)  > 0){  /* the second time for when it was created */
-                    FIXME("(%p) Something's still holding the implicite swapchain\n",This);
+                    FIXME("(%p) Something's still holding the implicit swapchain\n",This);
                 }
             }
 
@@ -405,7 +405,7 @@ HRESULT WINAPI IWineD3DDeviceImpl_Create
        memset(object->streamFreq, 1, sizeof(object->streamFreq));
     }
 
-    /* Reset the ref and type after kluging it */
+    /* Reset the ref and type after kludging it */
     object->wineD3DDevice = This;
     object->ref           = 1;
     object->blockType     = Type;
@@ -1034,9 +1034,9 @@ HRESULT WINAPI IWineD3DDeviceImpl_Create
     {
         IWineD3DSwapChain *implSwapChain;
         if (D3D_OK != IWineD3DDevice_GetSwapChain(iface, 0, &implSwapChain)) {
-            /* The first time around we create the context that is shared with all other swapchians and render targets */
+            /* The first time around we create the context that is shared with all other swapchains and render targets */
             object->glCtx = glXCreateContext(object->display, object->visInfo, NULL, GL_TRUE);
-            TRACE("Creating implicite context for vis %p, hwnd %p\n", object->display, object->visInfo);
+            TRACE("Creating implicit context for vis %p, hwnd %p\n", object->display, object->visInfo);
         } else {
 
             TRACE("Creating context for vis %p, hwnd %p\n", object->display, object->visInfo);
@@ -1071,9 +1071,9 @@ HRESULT WINAPI IWineD3DDeviceImpl_Create
    *******************/
 
    /**
-   * TODO: MSDNsays that we are only allowed one fullscreen swapchain per device,
+   * TODO: MSDN says that we are only allowed one fullscreen swapchain per device,
    * so we should really check to see if their is a fullscreen swapchain already
-   * I think Windows and X have differnt ideas about fullscreen, does a single head count as full screen?
+   * I think Windows and X have different ideas about fullscreen, does a single head count as full screen?
     **************************************/
 
    if (!*(pPresentationParameters->Windowed)) {
@@ -1303,7 +1303,7 @@ HRESULT WINAPI IWineD3DDeviceImpl_Create
     return hr;
 }
 
-/** NOTE: These are ahead of the other getters and setters to save using a forward declartion **/
+/** NOTE: These are ahead of the other getters and setters to save using a forward declaration **/
 UINT     WINAPI  IWineD3DDeviceImpl_GetNumberOfSwapChains(IWineD3DDevice *iface) {
     IWineD3DDeviceImpl *This = (IWineD3DDeviceImpl *)iface;
 
@@ -1483,7 +1483,7 @@ HRESULT WINAPI IWineD3DDeviceImpl_GetStr
 }
 
 /*****
- * Get / Set & Multipy Transform
+ * Get / Set & Multiply Transform
  *****/
 HRESULT  WINAPI  IWineD3DDeviceImpl_SetTransform(IWineD3DDevice *iface, D3DTRANSFORMSTATETYPE d3dts, CONST D3DMATRIX* lpmatrix) {
     IWineD3DDeviceImpl *This = (IWineD3DDeviceImpl *)iface;
@@ -4797,7 +4797,7 @@ HRESULT WINAPI IWineD3DDeviceImpl_SetRen
     }
 
     /* MSDN says that null disables the render target
-    but a device must always be associatated with a render target
+    but a device must always be associated with a render target
     nope MSDN says that we return invalid call to a null rendertarget with an index of 0
 
     see http://msdn.microsoft.com/library/default.asp?url=/library/en-us/directx9_c/directx/graphics/programmingguide/AdvancedTopics/PixelPipe/MultipleRenderTarget.asp
@@ -4823,16 +4823,16 @@ HRESULT WINAPI IWineD3DDeviceImpl_SetRen
         TRACE("clearing renderer\n");
         /* IWineD3DDeviceImpl_CleanRender(iface); */
         /* OpenGL doesn't support 'sharing' of the stencilBuffer so we may incure an extra memory overhead
-        depending on the renter target implemenattion being used.
+        depending on the renter target implementation being used.
         A shared context implementation will share all buffers between all rendertargets (including swapchains),
-        implemenations that use serperate pbuffers for different swapchains or rendertargets will have to duplicate the
+        implementations that use separate pbuffers for different swapchains or rendertargets will have to duplicate the
         stencil buffer and incure an extra memory overhead */
         hr = IWineD3DDeviceImpl_ActiveRender(iface, pRenderTarget);
     }
 
     if (SUCCEEDED(hr)) {
         /* Finally, reset the viewport as the MSDN states. */
-        /* TODO: Repalace impl usage */
+        /* TODO: Replace impl usage */
         viewport.Height = ((IWineD3DSurfaceImpl *)This->renderTarget)->currentDesc.Height;
         viewport.Width  = ((IWineD3DSurfaceImpl *)This->renderTarget)->currentDesc.Width;
         viewport.X      = 0;
@@ -4858,9 +4858,9 @@ HRESULT WINAPI IWineD3DDeviceImpl_SetDep
         TRACE("Trying to do a NOP SetRenderTarget operation\n");
     }else{
         /** OpenGL doesn't support 'sharing' of the stencilBuffer so we may incure an extra memory overhead
         * depending on the renter target implemenattion being used.
         * A shared context implementation will share all buffers between all rendertargets (including swapchains),
         * implemenations that use serperate pbuffers for different swapchains or rendertargets will have to duplicate the
         * stencil buffer and incure an extra memory overhead
          ******************************************************/
 
@@ -4915,7 +4915,7 @@ HRESULT WINAPI IWineD3DDeviceImpl_CleanR
         glXDestroyPbuffer(swapchain->display, swapchain->drawable);
 #endif
         LEAVE_GL();
-        /* Set everything back to the way that it ws */
+        /* Set everything back the way it ws */
         swapchain->render_ctx = swapchain->glCtx;
         swapchain->drawable = swapchain->win;
     }
@@ -4923,8 +4923,8 @@ HRESULT WINAPI IWineD3DDeviceImpl_CleanR
 }
 
 /** FIXME: This is currently used called whenever SetRenderTarget or SetStencilBuffer are called
-* the functiolaity needs splitting up so that we don't do more than we should do.
-* this only seems to affect performance a little.
+* the functionality needs splitting up so that we don't do more than we should do.
+* this only seems to impact performance a little.
  ******************************/
 HRESULT WINAPI IWineD3DDeviceImpl_ActiveRender(IWineD3DDevice* iface,
                                                IWineD3DSurface *RenderSurface) {
@@ -4938,10 +4938,10 @@ HRESULT WINAPI IWineD3DDeviceImpl_Active
    * for others versions we'll have to use GLXPixmaps
    *
    * normally we must test GLX_VERSION_1_3 but nvidia headers are not correct
-   * as they implements GLX 1.3 but only define GLX_VERSION_1_2
+   * as they implement GLX 1.3 but only define GLX_VERSION_1_2
    * so only check OpenGL version
    * ..........................
-   * I don't belive that it is a problem with NVidia headers,
+   * I don't believe that it is a problem with NVidia headers,
    * XFree only supports GLX1.2, nVidia (and ATI to some extent) provide 1.3 functions
    * in GLX 1.2, there is no mention of the correct way to tell if the extensions are provided.
    * ATI Note:
@@ -4957,7 +4957,7 @@ HRESULT WINAPI IWineD3DDeviceImpl_Active
     int nAttribs = 0;
     IWineD3DSwapChain     *currentSwapchain;
     IWineD3DSwapChainImpl *swapchain;
-    /** TODO: get rid of Impl usage we should always create a zbuffer/stencil with our contexts if pussible,
+    /** TODO: get rid of Impl usage we should always create a zbuffer/stencil with our contexts if possible,
     * but switch them off if the StencilSurface is set to NULL
     ** *********************************************************/
     D3DFORMAT BackBufferFormat = ((IWineD3DSurfaceImpl *) RenderSurface)->resource.format;
@@ -4969,7 +4969,7 @@ HRESULT WINAPI IWineD3DDeviceImpl_Active
     IWineD3DSurface *tmp;
 
     /**TODO:
-        if StencilSurface == NULL && zBufferTarget != NULL then swtich the zbuffer off,
+        if StencilSurface == NULL && zBufferTarget != NULL then switch the zbuffer off,
         it StencilSurface != NULL && zBufferTarget == NULL switch it on
     */
 
@@ -4978,11 +4978,11 @@ HRESULT WINAPI IWineD3DDeviceImpl_Active
 
     /* PUSH2(GLX_BIND_TO_TEXTURE_RGBA_ATI, True); examples of this are few and far between (but I've got a nice working one!)*/
 
-    /** TODO: remove the reff to Impl (context manager should fis this!) **/
+    /** TODO: remove the reff to Impl (context manager should fix this!) **/
     IWineD3DSwapChainImpl *impSwapChain;
     IWineD3DDevice_GetSwapChain(iface, 0, (IWineD3DSwapChain **)&impSwapChain);
     if (NULL == impSwapChain){ /* NOTE: This should NEVER fail */
-        ERR("(%p) Failed to get a the implicite swapchain\n", iface);
+        ERR("(%p) Failed to get a the implicit swapchain\n", iface);
     }
 
     ENTER_GL();
@@ -5000,7 +5000,7 @@ HRESULT WINAPI IWineD3DDeviceImpl_Active
     cfgs = glXChooseFBConfig(impSwapChain->display, DefaultScreen(impSwapChain->display),
                                                      attribs, &nCfgs);
 
-    if (!cfgs){ /* OK we didn't find the exact config, so use any reasonably match */
+    if (!cfgs){ /* OK we didn't find the exact config, so use any reasonable match */
         /* TODO: fill in the 'requested' and 'current' depths, also make sure that's
            why we failed and only show this message once! */
         MESSAGE("Failed to find exact match, finding alternative but you may suffer performance issues, try changing xfree's depth to match the requested depth\n"); /**/
@@ -5030,7 +5030,7 @@ HRESULT WINAPI IWineD3DDeviceImpl_Active
 #ifdef EXTRA_TRACES
         glFlush();
         vcheckGLcall("glFlush");
-        /** This is only usefuly if the old render target was a swapchain,
+        /** This is only useful if the old render target was a swapchain,
         * we need to supercede this with a function that displays
         * the current buffer on the screen. This is easy to do in glx1.3 but
         * we need to do copy-write pixels in glx 1.2.
@@ -5043,7 +5043,7 @@ HRESULT WINAPI IWineD3DDeviceImpl_Active
     }
 
     if (IWineD3DSurface_GetContainer(This->renderTarget, &IID_IWineD3DSwapChain, (void **)&currentSwapchain) != D3D_OK){
         /* the selected render target doesn't belong to a swapchain, so use the devices implicite swapchain */
         IWineD3DDevice_GetSwapChain(iface, 0, &currentSwapchain);
     }
 
@@ -5096,21 +5096,21 @@ HRESULT WINAPI IWineD3DDeviceImpl_Active
                 ||  Height > ((IWineD3DSurfaceImpl *)This->renderTarget)->currentDesc.Height))) {
 
         /** ********************************************************************
-        * This code is far too leaky to be usefull IWineD3DDeviceImpl_CleanRender
-        * doesn't seem to work properly and creating a new context Every time is 'extream' overkill.
+        * This code is far too leaky to be useful. IWineD3DDeviceImpl_CleanRender
+        * doesn't seem to work properly and creating a new context every time is 'extremely' overkill.
         * The code does however work, and should be moved to a context manager to
         * manage caching of pbuffers or render to texture are appropriate.
         *
-        * There are some real speed vs compatability issues here:
+        * There are some real speed vs compatibility issues here:
         *    we should really use a new context for every texture, but that eats ram.
         *    we should also be restoring the texture to the pbuffer but that eats CPU
         *    we can also 'reuse' the current pbuffer if the size is larger than the requested buffer,
         *    but if this means reusing the display backbuffer then we need to make sure that
         *    states are correctly preserved.
         * In many cases I would expect that we can 'skip' some functions, such as preserving states,
-        * and gain a good performance increase at the cost of compatability.
+        * and gain a good performance increase at the cost of compatibility.
         * I would suggest that, when this is the case, a user configurable flag be made
-        * available, alowing the user to choose the best emmulated experiance for them.
+        * available, allowing the user to choose the best emulated experience for them.
          *********************************************************************/
 
         /**
@@ -5183,7 +5183,7 @@ HRESULT WINAPI IWineD3DDeviceImpl_Active
         /** TODO: We may need to copy the bits into the buffer,
         * this should !!ONLY!! be done if an operation is performed on the target
         * without it being cleared and the buffer is not discardable.
-        * (basicly only bother preserving the contents if there's a possiblity that it will be reused)
+        * (basically only bother preserving the contents if there's a possibility that it will be reused)
         ** *********************************************************************/
         impSwapChain->drawable = newDrawable;
         impSwapChain->render_ctx = newContext;
@@ -299,12 +299,12 @@ ULONG WINAPI IWineD3DDeviceImpl_Release(
             IUnknown* swapChainParent;
 
-            /* Release all of the swapchains, except the implicite swapchain (#0) */
+            /* Release all of the swapchains, except the implicit swapchain (#0) */
             for(i = 1; i < This->numberOfSwapChains; i++){
                 /*  TODO: don't access swapchains[x] directly! */
@@ -4858,9 +4858,9 @@ HRESULT WINAPI IWineD3DDeviceImpl_SetDep
     }else{
         /** OpenGL doesn't support 'sharing' of the stencilBuffer so we may incure an extra memory overhead
-        * depending on the renter target implemenattion being used.
+        * depending on the renter target implementation being used.
         * A shared context implementation will share all buffers between all rendertargets (including swapchains),
@@ -4858,9 +4858,9 @@ HRESULT WINAPI IWineD3DDeviceImpl_SetDep
         * A shared context implementation will share all buffers between all rendertargets (including swapchains),
-        * implemenations that use serperate pbuffers for different swapchains or rendertargets will have to duplicate the
+        * implementations that use separate pbuffers for different swapchains or rendertargets will have to duplicate the
         * stencil buffer and incure an extra memory overhead
          ******************************************************/
@@ -5043,7 +5043,7 @@ HRESULT WINAPI IWineD3DDeviceImpl_Active
 
     if (IWineD3DSurface_GetContainer(This->renderTarget, &IID_IWineD3DSwapChain, (void **)&currentSwapchain) != D3D_OK){
-        /* the selected render target doesn't belong to a swapchain, so use the devices implicite swapchain */
+        /* the selected render target doesn't belong to a swapchain, so use the devices implicit swapchain */
         IWineD3DDevice_GetSwapChain(iface, 0, &currentSwapchain);
     }
Index: dlls/wined3d/directx.c
===================================================================
RCS file: /var/cvs/wine/dlls/wined3d/directx.c,v
retrieving revision 1.38
diff -u -p -r1.38 directx.c
--- dlls/wined3d/directx.c	10 Jul 2005 17:48:07 -0000	1.38
+++ dlls/wined3d/directx.c	10 Jul 2005 19:58:44 -0000
@@ -1582,8 +1582,8 @@ HRESULT  WINAPI  IWineD3DImpl_CreateDevi
         IWineD3DStateBlock_AddRef((IWineD3DStateBlock*)object->updateStateBlock);
         /* Setup surfaces for the backbuffer, frontbuffer and depthstencil buffer */
 
-        /* Setup the  implicite swapchain */
-        TRACE("Creating implicite swapchain\n");
+        /* Setup the implicit swapchain */
+        TRACE("Creating implicit swapchain\n");
 
         if (D3D_OK == D3DCB_CreateAdditionalSwapChain((IUnknown *) object->parent, pPresentationParameters, (IWineD3DSwapChain **)&swapchain) && swapchain != NULL) {
 
Index: dlls/wined3d/surface.c
===================================================================
RCS file: /var/cvs/wine/dlls/wined3d/surface.c,v
retrieving revision 1.11
diff -u -p -r1.11 surface.c
--- dlls/wined3d/surface.c	7 Jul 2005 20:35:05 -0000	1.11
+++ dlls/wined3d/surface.c	7 Jul 2005 22:31:52 -0000
@@ -308,14 +308,14 @@ HRESULT WINAPI IWineD3DSurfaceImpl_LockR
 
  /* Here's what we have to do:
             See if the swapchain has the same context as the renderTarget or the surface is the render target.
-            Otherwise, see if were sharing a context with the implicite swapchain (because were using a shared context model!)
-            and use the fron back buffer as required.
+            Otherwise, see if were sharing a context with the implicit swapchain (because we're using a shared context model!)
+            and use the front back buffer as required.
             if not, we need to switch contexts and then switchback at the end.
          */
         IWineD3DSurface_GetContainer(iface, &IID_IWineD3DSwapChain, (void **)&swapchain);
         IWineD3DSurface_GetContainer(myDevice->renderTarget, &IID_IWineD3DSwapChain, (void **)&targetSwapChain);
 
         /* NOTE: In a shared context environment the renderTarget will use the same context as the implicite swapchain (we're not in a shared environment yet! */
         if ((swapchain == targetSwapChain && targetSwapChain != NULL) || iface == myDevice->renderTarget) {
                 if (iface == myDevice->renderTarget || iface == swapchain->backBuffer) {
                     TRACE("locking back buffer\n");
@@ -333,7 +333,7 @@ HRESULT WINAPI IWineD3DSurfaceImpl_LockR
             IWineD3DSwapChainImpl *implSwapChain;
             IWineD3DDevice_GetSwapChain((IWineD3DDevice *)myDevice, 0, (IWineD3DSwapChain **)&implSwapChain);
             if (swapchain->glCtx == implSwapChain->render_ctx && swapchain->drawable == implSwapChain->win) {
                     /* This will fail for the implicite swapchain, which is why there needs to be a context manager */
                     if (iface == swapchain->backBuffer) {
                         glReadBuffer(GL_BACK);
                     }else if (iface == swapchain->frontBuffer) {
@@ -376,8 +376,8 @@ HRESULT WINAPI IWineD3DSurfaceImpl_LockR
             GLenum format = D3DFmt2GLFmt(myDevice, This->resource.format);
             GLenum type   = D3DFmt2GLType(myDevice, This->resource.format);
 #if 0
-            /* Bizarly it's takes 120 millseconds to get an 800x600 region a line at a time, but only 10 to get the whole lot every time,
-            *  This is on an ATI9600, and may be format dependant, anyhow this hack makes this demo dx9_2d_demo_game
+            /* Bizarly it takes 120 millseconds to get an 800x600 region a line at a time, but only 10 to get the whole lot every time,
+            *  This is on an ATI9600, and may be format dependent, anyhow this hack makes this demo dx9_2d_demo_game
             *  run ten times faster!
             * ************************************/
             BOOL ati_performance_hack = FALSE;
@@ -308,14 +308,14 @@ HRESULT WINAPI IWineD3DSurfaceImpl_LockR
         IWineD3DSurface_GetContainer(myDevice->renderTarget, &IID_IWineD3DSwapChain, (void **)&targetSwapChain);
 
-        /* NOTE: In a shared context environment the renderTarget will use the same context as the implicite swapchain (we're not in a shared environment yet! */
+        /* NOTE: In a shared context environment the renderTarget will use the same context as the implicit swapchain (we're not in a shared environment yet! */
         if ((swapchain == targetSwapChain && targetSwapChain != NULL) || iface == myDevice->renderTarget) {
                 if (iface == myDevice->renderTarget || iface == swapchain->backBuffer) {
@@ -333,7 +333,7 @@ HRESULT WINAPI IWineD3DSurfaceImpl_LockR
             IWineD3DDevice_GetSwapChain((IWineD3DDevice *)myDevice, 0, (IWineD3DSwapChain **)&implSwapChain);
             if (swapchain->glCtx == implSwapChain->render_ctx && swapchain->drawable == implSwapChain->win) {
-                    /* This will fail for the implicite swapchain, which is why there needs to be a context manager */
+                    /* This will fail for the implicit swapchain, which is why there needs to be a context manager */
                     if (iface == swapchain->backBuffer) {
                         glReadBuffer(GL_BACK);
Index: dlls/wined3d/swapchain.c
===================================================================
RCS file: /var/cvs/wine/dlls/wined3d/swapchain.c,v
retrieving revision 1.1
diff -u -p -r1.1 swapchain.c
--- dlls/wined3d/swapchain.c	23 Jun 2005 11:05:24 -0000	1.1
+++ dlls/wined3d/swapchain.c	7 Jul 2005 22:45:23 -0000
@@ -145,7 +145,7 @@ HRESULT WINAPI IWineD3DSwapChainImpl_Pre
             FIXME("Unable to render to a destination window %d\n", (int)hDestWindowOverride );
             if(This == swapChainImpl){
                 /* FIXME: this will be fixed by moving to a context management system */
-                FIXME("Cannot change the target of the implicite swapchain\n");
+                FIXME("Cannot change the target of the implicit swapchain\n");
             }else{
                 HDC               hDc;
                 XVisualInfo       template;
@@ -178,7 +178,7 @@ HRESULT WINAPI IWineD3DSwapChainImpl_Pre
                     LEAVE_GL();
                     return D3DERR_NOTAVAILABLE;
                 }
                 /* Now we have problems? well not really we just need to know what the implicite context is */
                 /* now destroy the old context and create a new one (we should really copy the buffers over, and do the whole make current thing! */
                 /* destroy the active context?*/
                 TRACE("Creating new context for %p %p %p\n",This->display, This->visInfo, swapChainImpl->glCtx);
@@ -189,7 +189,7 @@ HRESULT WINAPI IWineD3DSwapChainImpl_Pre
                 }
                 This->drawable     = This->win;
                 This->render_ctx   = This->glCtx;
-                /* SEtup some default states TODO: apply the stateblock to the new context */
+                /* Setup some default states TODO: apply the stateblock to the new context */
                 /** save current context and drawable **/
                 currentContext  =   glXGetCurrentContext();
                 currentDrawable =   glXGetCurrentDrawable();
@@ -327,7 +327,7 @@ HRESULT WINAPI IWineD3DSwapChainImpl_Get
     TRACE("(%p) : iface(%p) pDestSurface(%p) \n", This, iface, pDestSurface);
     ENTER_GL();
 
-    /* check to see if it's the backbuffer or the frontbuffer being requested (to make sureteh data is upto date) */
+    /* check to see if it's the backbuffer or the frontbuffer being requested (to make sure the data is up to date) */
     format = D3DFmt2GLFmt(This->wineD3DDevice, surface->resource.format);
     type   = D3DFmt2GLType(This->wineD3DDevice, surface->resource.format);
     glReadBuffer(GL_FRONT);
@@ -178,7 +178,7 @@ HRESULT WINAPI IWineD3DSwapChainImpl_Pre
                     return D3DERR_NOTAVAILABLE;
                 }
-                /* Now we have problems? well not really we just need to know what the implicite context is */
+                /* Now we have problems? well not really we just need to know what the implicit context is */
                 /* now destroy the old context and create a new one (we should really copy the buffers over, and do the whole make current thing! */
                 /* destroy the active context?*/